@@ -14,7 +14,7 @@
 
 import json
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import forms
 from horizon import messages
